@@ -9,7 +9,7 @@ from oort.shared.config import get_logger, write_config_value
 from oort.shared.models import Status, Substatus, Upload
 from .context import Context
 
-logger = get_logger()
+logger = get_logger('server')
 
 main = Blueprint('main', __name__)
 
@@ -17,7 +17,8 @@ main = Blueprint('main', __name__)
 @main.route('/')
 @main.route('/index')
 def index():
-    return render_template('index.html', context=app.config['context'].to_dict())
+    context: Context = app.config['context']
+    return render_template('index.html', context=context.to_dict())
 
 
 @main.route('/login', methods=['POST'])
@@ -25,20 +26,26 @@ def login():
     result, error = ArcsecondAPI.login(request.form.get('username'),
                                        request.form.get('password'),
                                        request.form.get('subdomain'),
+                                       upload_key=True,
                                        debug=app.config['context'].debug)
-    app.config['context']['login_error'] = json.loads(error) if error else None
+    # No: TypeError: 'Context' object does not support item assignment
+    # app.config['context']['login_error'] = json.loads(error) if error else None
     return redirect(url_for('main.index'))
 
 
 @main.route('/update')
 def update():
-    write_config_value('server', 'selected_folder', request.args.get("selectedFolder", ''))
-    return Response({}, mimetype='application/json')
+    if request.args.get("selectedFolder", ''):
+        write_config_value('server', 'selected_folder', request.args.get("selectedFolder", ''))
+        return Response({}, mimetype='application/json')
+    elif request.args.get("uploader", ''):
+        context: Context = app.config['context']
+        context.updateUploader(request.args.get("uploader", ''))
+        return redirect(url_for('main.index'))
 
 
 @main.route('/uploads')
 def uploads():
-    # print(app.config)
     context: Context = app.config['context']
 
     def generate():
