@@ -9,7 +9,7 @@ from oort.server.errors import InvalidOrganisationTelescopeOortCloudError, Inval
 from oort.shared.config import get_config_upload_folder_sections
 from oort.shared.identity import Identity
 from tests.utils import (
-    TEST_LOGIN_API_KEY,
+    TEST_LOGIN_UPLOAD_KEY,
     TEST_LOGIN_ORG_ROLE,
     TEST_LOGIN_ORG_SUBDOMAIN,
     TEST_LOGIN_USERNAME,
@@ -34,7 +34,7 @@ def test_cli_folders_with_options_org_as_o_but_no_telescope():
             patch.object(ArcsecondAPI, 'list', return_value=([TEL_DETAILS, ], None)) as mock_list_org_telescopes:
         with pytest.raises(InvalidWatchOptionsOortCloudError):
             o, organisation, t, telescope, astronomer = TEST_LOGIN_ORG_SUBDOMAIN, None, None, None, (None, None)
-            username, api_key, org_subdomain, org_role, tel_details = \
+            username, upload_key, org_subdomain, org_role, tel_details = \
                 parse_upload_watch_options(o, organisation, t, telescope, astronomer, True)
 
         assert mock_read_org.call_count == 1
@@ -51,7 +51,7 @@ def test_cli_folders_with_options_org_as_o_but_invalid_telescope():
 
         with pytest.raises(InvalidOrganisationTelescopeOortCloudError):
             o, organisation, t, telescope, astronomer = TEST_LOGIN_ORG_SUBDOMAIN, None, 'dummy', None, (None, None)
-            username, api_key, org_subdomain, org_role, tel_details = \
+            username, upload_key, org_subdomain, org_role, tel_details = \
                 parse_upload_watch_options(o, organisation, t, telescope, astronomer, True)
 
         assert mock_read.call_count == 2
@@ -66,13 +66,13 @@ def test_cli_folders_with_options_org_as_o_and_t():
         mock_read.side_effect = [(ORG_DETAILS, None), (TEL_DETAILS, None)]
 
         o, organisation, t, telescope, astronomer = TEST_LOGIN_ORG_SUBDOMAIN, None, TEL_UUID, None, (None, None)
-        username, api_key, org_subdomain, org_role, tel_details = \
+        username, upload_key, org_subdomain, org_role, tel_details = \
             parse_upload_watch_options(o, organisation, t, telescope, astronomer, True)
 
         # Assert
         assert mock_read.call_count == 2
         assert username == TEST_LOGIN_USERNAME
-        assert api_key == TEST_LOGIN_API_KEY
+        assert upload_key == TEST_LOGIN_UPLOAD_KEY
         assert org_subdomain == TEST_LOGIN_ORG_SUBDOMAIN
         assert org_role == TEST_LOGIN_ORG_ROLE
         assert TEL_DETAILS == tel_details
@@ -87,14 +87,14 @@ def test_cli_folders_custom_astronomer_with_o_and_t_options_and_valid_upload_key
         mock_read.side_effect = [(ORG_DETAILS, None), (TEL_DETAILS, None), (CUSTOM_ASTRONOMER_DETAILS, None)]
 
         o, organisation, t, telescope, astronomer = TEST_LOGIN_ORG_SUBDOMAIN, None, TEL_UUID, None, CUSTOM_ASTRONOMER
-        username, api_key, org_subdomain, org_role, tel_details = \
+        username, upload_key, org_subdomain, org_role, tel_details = \
             parse_upload_watch_options(o, organisation, t, telescope, astronomer, True)
 
         # Assert
         assert mock_list.call_count == 1
         assert mock_read.call_count == 3
         assert username == astronomer[0]
-        assert api_key == astronomer[1]
+        assert upload_key == astronomer[1]
         assert org_subdomain == TEST_LOGIN_ORG_SUBDOMAIN
         assert org_role == TEST_LOGIN_ORG_ROLE
         assert TEL_DETAILS == tel_details
@@ -103,7 +103,7 @@ def test_cli_folders_custom_astronomer_with_o_and_t_options_and_valid_upload_key
 
         save_upload_folders(folders,
                             username,
-                            api_key,
+                            upload_key,
                             org_subdomain,
                             org_role,
                             TEL_DETAILS,
@@ -112,7 +112,7 @@ def test_cli_folders_custom_astronomer_with_o_and_t_options_and_valid_upload_key
         for folder_section in get_config_upload_folder_sections():
             identity = Identity.from_folder_section(folder_section)
             assert identity.username == username
-            assert identity.api_key == api_key
+            assert identity.upload_key == upload_key
             assert identity.subdomain == org_subdomain
             assert identity.role == org_role
             assert identity.telescope == TEL_UUID
